Index: funcs/func_curl.c
===================================================================
--- funcs/func_curl.c	(revision 124742)
+++ funcs/func_curl.c	(working copy)
@@ -87,7 +87,6 @@
 		return -1;
 
 	curl_easy_setopt(*curl, CURLOPT_NOSIGNAL, 1);
-	curl_easy_setopt(*curl, CURLOPT_TIMEOUT, 180);
 	curl_easy_setopt(*curl, CURLOPT_WRITEFUNCTION, WriteMemoryCallback);
 	curl_easy_setopt(*curl, CURLOPT_USERAGENT, global_useragent);
 
@@ -103,13 +102,14 @@
 
 AST_THREADSTORAGE_CUSTOM(curl_instance, curl_instance_init, curl_instance_cleanup);
 
-static int curl_internal(struct MemoryStruct *chunk, char *url, char *post)
+static int curl_internal(struct MemoryStruct *chunk, char *url, char *post, int timeout)
 {
 	CURL **curl;
 
 	if (!(curl = ast_threadstorage_get(&curl_instance, sizeof(*curl))))
 		return -1;
 
+	curl_easy_setopt(*curl, CURLOPT_TIMEOUT, timeout);
 	curl_easy_setopt(*curl, CURLOPT_URL, url);
 	curl_easy_setopt(*curl, CURLOPT_WRITEDATA, (void *) chunk);
 
@@ -129,6 +129,9 @@
 static int acf_curl_exec(struct ast_channel *chan, const char *cmd, char *info, char *buf, size_t len)
 {
 	struct MemoryStruct chunk = { NULL, 0 };
+	const char *user_timeout;
+	int timeout = 180;
+	int i = 0;
 	AST_DECLARE_APP_ARGS(args,
 		AST_APP_ARG(url);
 		AST_APP_ARG(postdata);
@@ -141,12 +144,20 @@
 		return -1;
 	}
 
-	AST_STANDARD_APP_ARGS(args, info);	
+	AST_STANDARD_APP_ARGS(args, info);
+	user_timeout = pbx_builtin_getvar_helper(chan, "CURL_TIMEOUT");
+	if (user_timeout){
+	    if ((sscanf(user_timeout, "%d", &i) == 1) && (i > -1)) {
+		    timeout = i;
+	    } else {
+		    ast_log(LOG_WARNING, "Timeout value must be numeric\n");
+	    }
+	}	
 
 	if (chan)
 		ast_autoservice_start(chan);
 
-	if (!curl_internal(&chunk, args.url, args.postdata)) {
+	if (!curl_internal(&chunk, args.url, args.postdata, timeout)) {
 		if (chunk.memory) {
 			chunk.memory[chunk.size] = '\0';
 			if (chunk.memory[chunk.size - 1] == 10)
@@ -171,7 +182,8 @@
 	.syntax = "CURL(url[,post-data])",
 	.desc =
 	"  url       - URL to retrieve\n"
-	"  post-data - Optional data to send as a POST (GET is default action)\n",
+	"  post-data - Optional data to send as a POST (GET is default action)\n"
+	"The default timeout is 180 seconds and can be overwritten by setting the CURL_TIMEOUT channel variable\n",
 	.read = acf_curl_exec,
 };
 
